import { useNavigate, useParams } from "react-router-dom";
import {
  deleteLessonContent,
  lessonContents,
  lessonThumbnail,
  setEditorActive,
  setLessonContent,
  setLessonThumbnailTitle,
} from "./lessonPageEditorSlice";
import { useEffect } from "react";
import { useDispatch, useSelector } from "react-redux";
import { Converter, LessonContent } from "../LessonPage";
import { Card, Flex, Typography } from "antd";
import { DeleteOutlined } from "@ant-design/icons";
import { Constants } from "../../../core/utils/utils";
import HeaderBar from "../../../core/components/Header";
import img from "../LessonPage/pexels-photo-302902.webp";

export default function LessonPageEditor() {
  const { lessonId } = useParams();
  const navigate = useNavigate();

  const dispatch = useDispatch();
  const lnContents = useSelector(lessonContents);
  const lnThumbnail = useSelector(lessonThumbnail);

  useEffect(() => {
    dispatch(setEditorActive(true));

    return () => {
      dispatch(setEditorActive(false));
    };
  }, []);

  return (
    <>
      <HeaderBar
        theme="light"
        backTo={Constants.ROUTE_PATHS.LESSIONS.PAGE.replace(
          ":lessonId",
          lessonId as string
        )}
        onView={() =>
          navigate(
            Constants.ROUTE_PATHS.LESSIONS.PAGE.replace(
              ":lessonId",
              lessonId as string
            )
          )
        }
      />

      <Flex justify="center" style={{ paddingTop: 24 }}>
        <Flex justify="center" vertical gap={16}>
          <Card
            style={{
              width: 800,
              maxWidth: 800,
            }}
          >
            <Flex vertical={false} style={{ gap: 16 }}>
              <img src={img} alt="img1" style={{ height: 140 }} />

              <Flex align="center" style={{ width: "100%" }}>
                <Typography.Title
                  level={2}
                  editable={{
                    triggerType: "text" as any,
                    tooltip: "click to edit text",
                    onChange: (event) =>
                      dispatch(setLessonThumbnailTitle(event)),
                  }}
                  style={{
                    width: "100%",
                  }}
                >
                  {lnThumbnail.title}
                </Typography.Title>
              </Flex>
            </Flex>
          </Card>

          <Card
            style={{
              width: 800,
              maxWidth: 800,
            }}
          >
            <Flex vertical gap={16}>
              {lnContents.map((lnContent) => (
                <Flex key={lnContent.id}>
                  <Converter
                    mode="edititable"
                    lessonContent={lnContent}
                    onEdit={(data) =>
                      dispatch(
                        setLessonContent({
                          id: lnContent.id,
                          data: data,
                        })
                      )
                    }
                  />

                  <DeleteOutlined
                    onClick={() => {
                      console.log("delete", lnContent.id);
                      dispatch(deleteLessonContent(lnContent.id));
                    }}
                  />
                </Flex>
              ))}
            </Flex>
          </Card>
        </Flex>
      </Flex>
    </>
  );
}

export function StandardEditorCompontent(type: number): LessonContent {
  return {
    id: Math.floor(Math.random() * 100).toString(),
    position: 1,
    type: type,
    data: "Some data",
  };
}
