import { createSlice } from "@reduxjs/toolkit";
import { LessonContent } from "../LessonPage";
import { StandardEditorCompontent } from ".";

export const lessonPageEditorSlice = createSlice({
  name: "lessonPageEditor",
  initialState: {
    editorActive: false,
    lessonThumbnail: {
      img: "",
      title: "Test",
    },
    lessonContents: [] as LessonContent[],
  },
  reducers: {
    setEditorActive: (state, action) => {
      state.editorActive = action.payload;
    },
    addLessonContent: (state, action) => {
      state.lessonContents.push(StandardEditorCompontent(action.payload));
    },
    deleteLessonContent: (state, action) => {
      state.lessonContents = state.lessonContents.filter(
        (content) => content.id !== action.payload
      );
    },
    setLessonContent: (state, action) => {
      const index = state.lessonContents.findIndex(
        (content) => content.id === action.payload.id
      );

      state.lessonContents[index].data = action.payload.data;
    },
    setLessonThumbnailTitle: (state, action) => {
      state.lessonThumbnail.title = action.payload;
    },
  },
  selectors: {
    editorActive: (state) => state.editorActive,
    lessonContents: (state) => state.lessonContents,
    lessonThumbnail: (state) => state.lessonThumbnail,
  },
});

export const {
  setEditorActive,
  addLessonContent,
  deleteLessonContent,
  setLessonContent,
  setLessonThumbnailTitle,
} = lessonPageEditorSlice.actions;

export const { editorActive, lessonContents, lessonThumbnail } =
  lessonPageEditorSlice.selectors;
